# Generated by roxygen2: do not edit by hand

export(dict_index)
export(download_dic)
export(list_dic)
export(pos)
export(posParallel)
export(set_dic)
import(Rcpp)
importFrom(Rcpp,sourceCpp)
importFrom(RcppParallel,RcppParallelLibs)
useDynLib(RcppMeCab, .registration=TRUE)
