# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

dictIndexRcpp <- function(args) {
    .Call(`_RcppMeCab_dictIndexRcpp`, args)
}

dictionaryInfoRcpp <- function(sys_dic, user_dic) {
    .Call(`_RcppMeCab_dictionaryInfoRcpp`, sys_dic, user_dic)
}

posParallelJoinRcpp <- function(text, sys_dic, user_dic) {
    .Call(`_RcppMeCab_posParallelJoinRcpp`, text, sys_dic, user_dic)
}

posParallelDFRcpp <- function(text, sys_dic, user_dic) {
    .Call(`_RcppMeCab_posParallelDFRcpp`, text, sys_dic, user_dic)
}

posParallelRcpp <- function(text, sys_dic, user_dic) {
    .Call(`_RcppMeCab_posParallelRcpp`, text, sys_dic, user_dic)
}

posRcpp <- function(text, sys_dic, user_dic) {
    .Call(`_RcppMeCab_posRcpp`, text, sys_dic, user_dic)
}

posJoinRcpp <- function(text, sys_dic, user_dic) {
    .Call(`_RcppMeCab_posJoinRcpp`, text, sys_dic, user_dic)
}

posLoopRcpp <- function(text, sys_dic, user_dic) {
    .Call(`_RcppMeCab_posLoopRcpp`, text, sys_dic, user_dic)
}

posLoopJoinRcpp <- function(text, sys_dic, user_dic) {
    .Call(`_RcppMeCab_posLoopJoinRcpp`, text, sys_dic, user_dic)
}

posDFRcpp <- function(text, sys_dic, user_dic) {
    .Call(`_RcppMeCab_posDFRcpp`, text, sys_dic, user_dic)
}

# Register entry points for exported C++ functions
methods::setLoadAction(function(ns) {
    .Call(`_RcppMeCab_RcppExport_registerCCallable`)
})
