% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RcppMeCab-package.r
\docType{package}
\name{RcppMeCab}
\alias{RcppMeCab-package}
\alias{RcppMeCab}
\title{RcppMeCab: Rcpp Wrapper for MeCab Library}
\description{
R package based on \code{Rcpp} for \code{MeCab}: Yet Another Part-of-Speech and
Morphological Analyzer (\url{http://taku910.github.io/mecab/}). It provides
install-time engine profiles and dictionaries for Japanese, Korean, and
Mandarin Chinese text. Runtime dictionary selection does not change the
installed engine. This package utilizes parallel programming for providing
highly efficient text preprocessing \code{posParallel()} function.
For installation, please refer to README.md file.
}
\details{
This package utilizes \code{MeCab} C API and \code{Rcpp} codes.
}
\references{
\itemize{
\item{\href{http://taku910.github.io/mecab/}{MeCab}}
\item{\href{https://www.rcpp.org/}{Rcpp: Seamless R and C++ Integration}}
\item{\href{http://eunjeon.blogspot.com}{Eunjeon project}}
}
}
\seealso{
Useful links:
\itemize{
  \item Report bugs at \url{https://github.com/junhewk/RcppMeCab/issues}
}

}
\author{
Junhewk Kim Taku Kudo
}
\keyword{Chinese}
\keyword{Japanese}
\keyword{Korean}
\keyword{MeCab}
\keyword{morpheme}
\keyword{nlp}
\keyword{part-of-speech}
